@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -695,10 +695,7 @@ gupnp_network_manager_dispose (GObject *object)
                 priv->cancellable = NULL;
         }
 
-        if (priv->system_bus != NULL) {
-                g_object_unref (priv->system_bus);
-                priv->system_bus = NULL;
-        }
+        g_clear_object (&(priv->system_bus));
 
         /* Call super */
         object_class = G_OBJECT_CLASS (gupnp_network_manager_parent_class);
